define([
    "dojo/_base/declare",
    "dojo/when",
    "dojox/mvc/getPlainValue",
    "dojox/mvc/at",
    "dojox/mvc/getStateful",

    "aps/_View",
    "aps/ResourceStore",
    "aps/Memory",

    "./displayError.js",

    "dojo/text!./newvps.json"
], function(
    declare,
    when,
    getPlainValue,
    at,
    getStateful,

    _View,
    Store,
    Memory,

    displayError,

    newVPS
) {
    return declare(_View, {
        init: function() {
            /* Define data sources */
            this.store = new Store({ target: "/aps/2/resources"});
            aps.app.model.set("editVPS", getStateful(JSON.parse(newVPS)));

            /* Define and return widgets */
            return [["aps/Panel", {id: this.genId("edit_panel1"), title: _("Server")}, [
                ["aps/FieldSet", {id: this.genId("edit_general")}, [
                    ["aps/TextBox", {
                        id: this.genId("edit_serverName"),
                        label: _("Name"),
                        value: at(aps.app.model.editVPS, "name"),
                        required: true
                    }],
                    ["aps/TextBox", {
                        id: this.genId("edit_description"),
                        label: _("Description"),
                        value: at(aps.app.model.editVPS, "description")
                    }]
                ]
                ]]],
                ["aps/Panel", {id: this.genId("edit_panel2"), title: _("Configuration")}, [
                    ["aps/FieldSet", {id: this.genId("edit_props")}, [
                        ["aps/Spinner", {
                            id: this.genId("edit_cpu"),
                            gridSize: 'md-3 xs-12',
                            label: _( "CPU Number"),
                            minimum: 1,
                            maximum: 16,
                            value: at(aps.app.model.editVPS.hardware.CPU, "number"),
                            step: 1
                        }],
                        ["aps/Spinner", {
                            id: this.genId("edit_disk"),
                            gridSize: 'md-3 xs-12',
                            label: _("Disk Space"),
                            minimum: 1,
                            maximum: 100,
                            value: at(aps.app.model.editVPS.hardware, "diskspace"),
                            legend: _("Gb"),
                            step: 1
                        }],
                        ["aps/Spinner", {
                            id: this.genId("edit_ram"),
                            gridSize: 'md-3 xs-12',
                            label: _("RAM"),
                            minimum: 128,
                            maximum: 8192,
                            value: at(aps.app.model.editVPS.hardware, "memory"),
                            legend: _("Mb"),
                            step: 128
                        }]
                    ]
                    ]]]
            ];
        },   // End of Init

        /* Handlers for the navigation buttons */
        onCancel: function() {
            aps.apsc.gotoView("servers");
        },

        onSubmit: function() {
            var page = this.byId("apsPageContainer");

            if (!page.validate()) {
                aps.apsc.cancelProcessing();
                return;
            }

            when(this.store.put(getPlainValue(aps.app.model.editVPS)),
                function() {
                    aps.apsc.gotoView("servers");
                },
                displayError
            );
        },

        onContext: function() {
            /* Getting VPS properties */
            this.store.get(aps.context.vars.vps.aps.id).then(function(vps){
                /* Collect the VPS properties in the model */
                aps.app.model.set("editVPS", getStateful(vps));
                aps.apsc.hideLoading(); /* Hide the loading visual layer */
            });
        },	// End of onContext

        onHide: function() {
            /* Reset widget fields to avoid flickering when opening another VPS */
            aps.app.model.set("editVPS", getStateful(JSON.parse(newVPS)));
        }	// End of onHide

    });		// End of Declare
});			// End of Define
