define([
	"dojo/_base/declare",
	"dojo/when",
	"dojox/mvc/getPlainValue",

	"aps/xhr",
	"aps/_View",
	"aps/ResourceStore",

	"./displayError"
], function (
	declare,
	when,
	getPlainValue,

	xhr,
	_View,
	Store,

	displayError
) {
	var subscriptionId;

	function createDnsRecord(vps) {
		var jsonData = {
			"aps": {
				"type": "http://aps-standard.org/types/dns/record/a/1.0"
			},
			"RRState": "active",
			"TTL": 3600,
			"source": vps.domainName + ".",
			"address": vps.ipAddress,
			"zone": {
				"aps": {
					"id": vps.domain.aps.id
				}
			}
		};
		return xhr("/aps/2/resources/" + vps.aps.id + "/records", {
			method: "POST",
			data: JSON.stringify(jsonData)
		});
	}

	return declare(_View, {
		init: function() {
			/* Create widgets */
			return ["aps/Panel", { id: "wizard_panel" }, [
					["aps/Output", {
						id: "wizard_contents",
						content: "<h2>Let's create one more server </h2>" +
								"Before getting started, make sure you have all necessary parameters: <br>" +
								"<ul> <li> CPU power - number of CPU cores" +
								"<li> Disk space - GB" +
								"<li> RAM space - MB"
                    }]
            ]];
		},

		onContext: function() {
			subscriptionId = aps.context.vars.context.aps.subscription;
			aps.context.wizardState.forEach(function(view) {
					view.visible = true;
				}
			);
			aps.apsc.wizardState(aps.context.wizardState);
			aps.apsc.hideLoading();
		},

		onNext: function() {
            /* Direct a user to the first view */
            if (aps.context.params.domainApsId) { // If we've come here from the DNS Manager
                aps.apsc.next(aps.context.params.domainApsId);
            }
            else aps.apsc.next();
		},

		onSubmit: function() {
			aps.context.subscriptionId = aps.context.vars.context.aps.subscription;

			var store = new Store({
				apsType: "http://aps-standard.org/samples/sample-dns/vps/1.0",
				target: "/aps/2/resources/" + aps.context.vars.context.aps.id + "/vpses"
			});

			var newVPS = aps.context.wizardData["http://aps-standard.org/samples/sample-dns#vps-props"]; // Receive data from the first step
			store.put(getPlainValue(newVPS)).then(function(vps) {
				return createDnsRecord(vps);
			}).then(function() {
				aps.apsc.gotoView("servers");
			}, displayError);
		}
	});
});
