define([
        "dojo/_base/declare",
        "dojox/mvc/getPlainValue",
        "dojox/mvc/at",
        "dojox/mvc/getStateful",
        "aps/_View",
        "aps/load",
        "aps/Memory",

        "./../displayError",

        /* Include JSON file that defines the default properties */
        "aps/json!./../newvps.json"
    ],
    function (declare, getPlainValue, at, getStateful, _View, load, Memory, displayError, newVPS) {
        var self;
        return declare(_View, {
            init: function () {
                self = this;

                /* Declare the data sources */
                var oses = new Memory({
                    idProperty: "value",
                    data: [
                        {value: "centos6", label: "CentOS 6"},
                        {value: "debian", label: "Debian"},
                        {value: "windows2008", label: "Windows 2008 Server"},
                        {value: "windows2012", label: "Windows 2012 Server"}
                    ]
                });

                this.model = getStateful({"newVPS": newVPS});

                /* Define and return widgets */
                return [
                    ["aps/Panel", {id: this.genId("srvNew1_form"), title: _("Server")}, [
                        ["aps/FieldSet", {title: true}, [
                            ["aps/TextBox", {
                                id: this.genId("srvNew1_serverName"),
                                label: _("Name"),
                                gridSize: "md-3 xs-12",
                                value: at(this.model.newVPS, "name"),
                                required: true
                            }],
                            ["aps/TextBox", {
                                id: this.genId("srvNew1_description"),
                                label: _("Description"),
                                gridSize: "md-3 xs-12",
                                value: at(this.model.newVPS, "description")
                            }]
                        ]]
                    ]],
                    ["aps/Panel", {id: this.genId("srvNew2_form"), title: _("Configuration")}, [
                        ["aps/FieldSet", {id: "srvNew1_", title: true}, [
                            ["aps/Select", {
                                id: this.genId("srvNew1_domain"),
                                label: _("Domains"),
                                gridSize: "md-3 xs-12",
                                value: at(this.model.newVPS.domain.aps, "id"),
                                labelAttr: "name"
                            }],
                            ["aps/TextBox", {
                                id: this.genId("srvNew1_ipAddress"),
                                label: _("IP Address"),
                                gridSize: "md-3 xs-12",
                                value: at(this.model.newVPS, "ipAddress"),
                                required: true
                            }],
                            ["aps/Select", {
                                id: this.genId("srvNew1_os"),
                                label: _("OS"),
                                gridSize: "md-3 xs-12",
                                value: at(this.model.newVPS.platform.OS, "name"),
                                store: oses
                            }],
                            ["aps/Spinner", {
                                id: this.genId("srvNew1_cpu"),
                                label: _("CPU Number"),
                                gridSize: "md-3 xs-12",
                                minimum: 1,
                                maximum: 16,
                                value: at(this.model.newVPS.hardware.CPU, "number"),
                                step: 1
                            }],
                            ["aps/Spinner", {
                                id: this.genId("srvNew1_disk"),
                                label: _("Disk Space"),
                                minimum: 1,
                                maximum: 100,
                                gridSize: "md-3 xs-12",
                                value: at(this.model.newVPS.hardware, "diskspace"),
                                legend: _("Gb"),
                                step: 1
                            }],
                            ["aps/Spinner", {
                                id: this.genId("srvNew1_ram"),
                                label: _("RAM"),
                                minimum: 128,
                                gridSize: "md-3 xs-12",
                                maximum: 8192,
                                value: at(this.model.newVPS.hardware, "memory"),
                                step: 128,
                                legend: _("Mb")
                            }]
                        ]]
                    ]]
                ];
            },	// End of Init

            onContext: function () {
                if (!aps.context.wizardData["http://aps-standard.org/samples/sample-dns#vps-props"]) {
                    this.model.set("newVPS", newVPS);

                    if (aps.context.vars.context.paDomains.length) {
                        this.model.newVPS.domain.aps.set("id", aps.context.vars.context.paDomains[0].aps.id);
                    }

                    var domains = new Memory({
                        idProperty: "aps.id",
                        data: aps.context.vars.context.paDomains
                    });
                    this.byId("srvNew1_domain").set('store', domains);
                }
                aps.apsc.hideLoading();
            },

            onNext: function () {
                /* Validate the values assigned to widgets */
                if (!this.validate()) {
                    aps.apsc.cancelProcessing();
                    return;
                }

                var domainSelect = this.byId("srvNew1_domain");
                this.model.newVPS.set("domainName", this.model.newVPS.name.replace(' ', '-') + "." +
                    domainSelect.getOption(this.model.newVPS.domain.aps.id)[0].label
                );

                /* Proceed to the next screen */
                aps.apsc.next(this.model.newVPS);
            }
        });
    });
